@@ -34,10 +34,6 @@
   void
 Draw_Structure( GtkWidget *drawingarea )
 {
-  /* Block motion events */
-  g_signal_handler_block
-	( (gpointer)drawingarea, structure_motion_handler );
-
   /* Abort if xnec2c may be quit by user */
   if( isFlagSet(MAIN_QUIT) )
 	return;
@@ -80,10 +76,6 @@ Draw_Structure( GtkWidget *drawingarea )
 
   cairo_destroy( cr );
 
-  /* Unblock motion events */
-  g_signal_handler_unblock(
-	  (gpointer)drawingarea, structure_motion_handler );
-
 } /* Draw_Structure() */
 
 /*-----------------------------------------------------------------------*/
@@ -161,12 +153,12 @@ New_Patch_Data( void )
 
   /* Allocate memory for patch line segments */
   mreq = (size_t)(2 * data.m) * sizeof(double);
-  mem_realloc( (void *)&data.px1, mreq, "in draw_structure.c" );
-  mem_realloc( (void *)&data.py1, mreq, "in draw_structure.c" );
-  mem_realloc( (void *)&data.pz1, mreq, "in draw_structure.c" );
-  mem_realloc( (void *)&data.px2, mreq, "in draw_structure.c" );
-  mem_realloc( (void *)&data.py2, mreq, "in draw_structure.c" );
-  mem_realloc( (void *)&data.pz2, mreq, "in draw_structure.c" );
+  mem_realloc( (void **)&data.px1, mreq, "in draw_structure.c" );
+  mem_realloc( (void **)&data.py1, mreq, "in draw_structure.c" );
+  mem_realloc( (void **)&data.pz1, mreq, "in draw_structure.c" );
+  mem_realloc( (void **)&data.px2, mreq, "in draw_structure.c" );
+  mem_realloc( (void **)&data.py2, mreq, "in draw_structure.c" );
+  mem_realloc( (void **)&data.pz2, mreq, "in draw_structure.c" );
 
   /* Find point furthest from xyz axes origin */
   r_max = 0.0;
@@ -404,6 +396,7 @@ Draw_Wire_Segments(	GdkSegment *segm, gint nseg )
 	/* To color structure segs */
 	double red = 0.0, grn = 0.0, blu = 0.0;
 	char label[11];
+	size_t s = sizeof( label );
 
 	/* Loop over all wire segs, find max current/charge */
 	if( crnt.newer )
@@ -425,9 +418,9 @@ Draw_Wire_Segments(	GdkSegment *segm, gint nseg )
 
 	  /* Show max value in color code label */
 	  if( isFlagSet(DRAW_CURRENTS) )
-		snprintf( label, 11, "%10.3E", cmax * (double)data.wlam );
+		snprintf( label, s, "%10.3E", cmax * (double)data.wlam );
 	  else
-		snprintf( label, 11, "%10.3E", cmax * 1.0E-6/(double)calc_data.fmhz );
+		snprintf( label, s, "%10.3E", cmax * 1.0E-6/(double)calc_data.fmhz );
 	  gtk_label_set_text(
 		  GTK_LABEL(lookup_widget(structure_drawingarea,
 			  "main_colorcode_maxlabel")), label );
@@ -680,10 +673,10 @@ Redo_Currents( gpointer udata )
 New_Structure_Projection_Angle(void)
 {
   /* sin and cos of structure rotation and inclination angles */
-  structure_proj_params.sin_wr = sin(structure_proj_params.Wr/(double)TD);
-  structure_proj_params.cos_wr = cos(structure_proj_params.Wr/(double)TD);
-  structure_proj_params.sin_wi = sin(structure_proj_params.Wi/(double)TD);
-  structure_proj_params.cos_wi = cos(structure_proj_params.Wi/(double)TD);
+  structure_proj_params.sin_wr = sin(structure_proj_params.Wr/(double)TODEG);
+  structure_proj_params.cos_wr = cos(structure_proj_params.Wr/(double)TODEG);
+  structure_proj_params.sin_wi = sin(structure_proj_params.Wi/(double)TODEG);
+  structure_proj_params.cos_wi = cos(structure_proj_params.Wi/(double)TODEG);
 
   /* Trigger a redraw of structure drawingarea */
   if( isFlagClear(INPUT_PENDING) )
@@ -706,7 +699,7 @@ Init_Struct_Drawing( void )
 {
   /* We need n segs for wires + 2m for patces */
   size_t mreq = (size_t)(data.n + 2*data.m) * sizeof(GdkSegment);
-  mem_realloc( (void *)&structure_segs, mreq, "in draw_structure.c" );
+  mem_realloc( (void **)&structure_segs, mreq, "in draw_structure.c" );
   New_Wire_Data();
   New_Patch_Data();
 }
@@ -730,12 +723,12 @@ Show_Viewer_Gain(
   {
 	char txt[8];
 
-	if( isFlagSet(ENABLE_RDPAT) && (calc_data.fstep >=0) )
+	if( isFlagSet(ENABLE_RDPAT) && (calc_data.fstep >= 0) )
 	{
-	  snprintf( txt, 8, "%7.2f",
+	  snprintf( txt, sizeof(txt), "%7.2f",
 		  Viewer_Gain(proj_params, calc_data.fstep) );
-	  txt[7] = '\0';
-	  gtk_entry_set_text( GTK_ENTRY(lookup_widget(window, widget)), txt );
+	  gtk_entry_set_text(
+		  GTK_ENTRY(lookup_widget(window, widget)), txt );
 	}
   }
 
