@@ -168,7 +168,7 @@ Set_Interaction_Matrix( void )
   /* Memory allocation for symmetry array */
   smat.nop = netcx.neq/netcx.npeq;
   size_t mreq = (size_t)(smat.nop * smat.nop) * sizeof( complex double);
-  mem_realloc( (void *)&smat.ssx, mreq, "in xnec2c.c" );
+  mem_realloc( (void **)&smat.ssx, mreq, "in xnec2c.c" );
 
   /* irngf is not used (NGF function not implemented) */
   int iresrv = data.np2m * (data.np + 2 * data.mp);
@@ -192,8 +192,8 @@ Set_Excitation( void )
 {
   if( (fpat.ixtyp >= 1) && (fpat.ixtyp <= 4) )
   {
-	tmp4= TA* calc_data.xpr4;
-	tmp5= TA* calc_data.xpr5;
+	tmp4= TORAD* calc_data.xpr4;
+	tmp5= TORAD* calc_data.xpr5;
 
 	if( fpat.ixtyp == 4)
 	{
@@ -204,9 +204,9 @@ Set_Excitation( void )
 	}
 	else
 	{
-	  tmp1= TA* calc_data.xpr1;
-	  tmp2= TA* calc_data.xpr2;
-	  tmp3= TA* calc_data.xpr3;
+	  tmp1= TORAD* calc_data.xpr1;
+	  tmp2= TORAD* calc_data.xpr2;
+	  tmp3= TORAD* calc_data.xpr3;
 	  tmp6= calc_data.xpr6;
 	} /* if( fpat.ixtyp == 4) */
 
@@ -625,8 +625,7 @@ Frequency_Loop( gpointer udata )
   if( isFlagSet(PLOT_ENABLED) )
   {
 	char txt[10];
-	snprintf( txt, 10, "%10.3f", (gdouble)calc_data.fmhz );
-	txt[9] = '\0';
+	snprintf( txt, sizeof(txt), "%10.3f", (gdouble)calc_data.fmhz );
 	gtk_entry_set_text( GTK_ENTRY(
 		  lookup_widget(freqplots_window, "freqplots_fmhz_entry")), txt );
   }
